==> org.eclipse.datatools.enablement.ibm.db2.luw.source_1.2.0.201701131441.jar: org/eclipse/datatools/enablement/ibm/db2/luw/catalog/LUWCatalogPrivilege.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2014 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.enablement.ibm.db2.luw.catalog;

import java.sql.Connection;

import org.eclipse.datatools.connectivity.sqm.core.rte.ICatalogObject;
import org.eclipse.datatools.connectivity.sqm.core.rte.RefreshManager;
import org.eclipse.datatools.enablement.ibm.IBMPluginActivator;
import org.eclipse.datatools.modelbase.sql.accesscontrol.Privilege;
import org.eclipse.datatools.modelbase.sql.accesscontrol.impl.PrivilegeImpl;
import org.eclipse.datatools.modelbase.sql.schema.Database;
import org.eclipse.emf.ecore.EAnnotation;
import org.eclipse.emf.ecore.EcoreFactory;

public class LUWCatalogPrivilege extends PrivilegeImpl implements ICatalogObject {

	public void refresh() {
		RefreshManager.getInstance().referesh(this);
	}

	public boolean isSystemObject() {
		return false;
	}	

	public Connection getConnection() {
		Database database = this.getCatalogDatabase();
		return ((LUWCatalogDatabase) database).getConnection();
	}
	
	public Database getCatalogDatabase() {
		return this.getGrantee().getDatabase();		
	}
	
	public static void setAsSystemGranted(Privilege privilege, boolean value) {
		EAnnotation eAnnotation = EcoreFactory.eINSTANCE.createEAnnotation();
		eAnnotation.setSource(IBMPluginActivator.PRIVILEGE_PROPERTY);
		eAnnotation.getDetails().put(IBMPluginActivator.PRIVILEGE_SYSTEM_GRANT, new Boolean (value).toString());
		privilege.getEAnnotations().add(eAnnotation);
	}
}

==> org.eclipse.datatools.enablement.ibm.db2.luw.source_1.3.0.202311071249.jar: org/eclipse/datatools/enablement/ibm/db2/luw/catalog/LUWCatalogPrivilege.java <==
/*******************************************************************************
 * Copyright (c) 2004, 2014 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.datatools.enablement.ibm.db2.luw.catalog;

import java.sql.Connection;

import org.eclipse.datatools.connectivity.sqm.core.rte.ICatalogObject;
import org.eclipse.datatools.connectivity.sqm.core.rte.RefreshManager;
import org.eclipse.datatools.enablement.ibm.IBMPluginActivator;
import org.eclipse.datatools.modelbase.sql.accesscontrol.Privilege;
import org.eclipse.datatools.modelbase.sql.accesscontrol.impl.PrivilegeImpl;
import org.eclipse.datatools.modelbase.sql.schema.Database;
import org.eclipse.emf.ecore.EAnnotation;
import org.eclipse.emf.ecore.EcoreFactory;

public class LUWCatalogPrivilege extends PrivilegeImpl implements ICatalogObject {

	public void refresh() {
		RefreshManager.getInstance().referesh(this);
	}

	public boolean isSystemObject() {
		return false;
	}	

	public Connection getConnection() {
		Database database = this.getCatalogDatabase();
		return ((LUWCatalogDatabase) database).getConnection();
	}
	
	public Database getCatalogDatabase() {
		return this.getGrantee().getDatabase();		
	}
	
	public static void setAsSystemGranted(Privilege privilege, boolean value) {
		EAnnotation eAnnotation = EcoreFactory.eINSTANCE.createEAnnotation();
		eAnnotation.setSource(IBMPluginActivator.PRIVILEGE_PROPERTY);
		eAnnotation.getDetails().put(IBMPluginActivator.PRIVILEGE_SYSTEM_GRANT, Boolean.valueOf(value).toString());
		privilege.getEAnnotations().add(eAnnotation);
	}
}
